@@ -380,6 +380,8 @@ class LanguageSelectorPkgCache(apt.Cache):
         for (code, lang) in self._localeinfo._lang.items():
             if code == 'zh':
                 continue
+            if code == 'no':
+                continue # hack for LP#773009
             li = LanguageInformation(self, code, lang)
             if [s for s in li.languagePkgList.itervalues() if s.available]:
                 res.append(li)
